import { Utils } from '@nativescript/core';
import { parseOptions } from './common';
export const showFilePicker = (options) => {
    options = parseOptions(options);
    const documentTypes = Utils.ios.collections.jsArrayToNSArray(['public.data']);
    const controller = UIDocumentPickerViewController.alloc().initWithDocumentTypesInMode(documentTypes, 0 /* Import */);
    return new Promise((res, rej) => {
        controller.delegate = MediafilepickerDocumentPickerDelegate.initWithOwner(new WeakRef(showFilePicker), res, rej);
        const app = UIApplication.sharedApplication;
        app.keyWindow.rootViewController.presentViewControllerAnimatedCompletion(controller, true, null);
    });
};
var MediafilepickerDocumentPickerDelegate = /** @class */ (function (_super) {
    __extends(MediafilepickerDocumentPickerDelegate, _super);
    function MediafilepickerDocumentPickerDelegate() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MediafilepickerDocumentPickerDelegate.initWithOwner = function (owner, resolve, reject) {
        this.resolve = function (file) { return setTimeout(function () { return resolve(file); }, 300); };
        this.reject = reject;
        var delegate = MediafilepickerDocumentPickerDelegate.new();
        delegate._owner = owner;
        return delegate;
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerDidPickDocumentAtURL = function (controller, url) {
        if (url) {
            MediafilepickerDocumentPickerDelegate.resolveNSUrl(url);
        }
        else {
            MediafilepickerDocumentPickerDelegate.resolve(null);
        }
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerDidPickDocumentsAtURLs = function (controller, urls) {
        if (urls && urls.count > 0) {
            MediafilepickerDocumentPickerDelegate.resolveNSUrl(urls[0]);
        }
        else {
            MediafilepickerDocumentPickerDelegate.resolve(null);
        }
    };
    MediafilepickerDocumentPickerDelegate.prototype.documentPickerWasCancelled = function (controller) {
        MediafilepickerDocumentPickerDelegate.resolve(null);
    };
    MediafilepickerDocumentPickerDelegate.resolveNSUrl = function (url) {
        var path = url.absoluteString.replace('file:///private', '');
        path = url.absoluteString.replace('file:///', '');
        var name = path.split('/').pop();
        MediafilepickerDocumentPickerDelegate.resolve({
            path: path,
            name: name,
            mime: getMime(name),
        });
    };
    MediafilepickerDocumentPickerDelegate.ObjCProtocols = [UIDocumentPickerDelegate];
    return MediafilepickerDocumentPickerDelegate;
}(NSObject));
const getMime = (fileName) => {
    const uti = UTTypeCreatePreferredIdentifierForTag(kUTTagClassFilenameExtension, fileName.split('.').pop(), null);
    const mime = UTTypeCopyPreferredTagWithClass(uti ? uti.takeRetainedValue() : null, kUTTagClassMIMEType);
    return mime ? mime.takeRetainedValue() : null;
};
//# sourceMappingURL=index.ios.js.map